<html>
<head>
<title>img0ch - GAvbg̕`r̉摜ꗗ</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="Robot" content="NOINDEX,NOFOLLOW">
<meta name="VERSION" content="<TMPL_VAR NAME=VERSION ESCAPE=HTML>">
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">

<table border="1" align="center" cellspacing="7" cellpadding="3" width="" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">

<?cs if:Banner ?><tr><td><?cs var:Banner ?></td></tr><?cs /if ?>

<tr><td>
<?cs if:DraftCount ?>
YIP<strong><?cs var:html_escape(DraftCount) ?></strong>̉܂B<br>
1ȏo߂ƎIɍ폜܂B<br>
<br>
<?cs each:item = Drafts ?>
<div align="center">
<img src="data:image/<?cs var:html_escape(item.type) ?>;base64,<?cs var:html_escape(item.image) ?>" alt="<?cs var:html_escape(item.id) ?>.<?cs var:html_escape(item.type) ?>" /><br>
<table border="1">
<tr><td>ύX</td><td><?cs var:html_escape(item.modified) ?></td></tr>
<tr><td>oߕb</td><td><?cs var:html_escape(item.ellapse) ?></td></tr>
<?cs if:item.animation ?><tr><td>PCH̃TCY</td><td><?cs var:html_escape(item.animation) ?> bytes</td></tr><?cs /if ?>
</table>
[<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=continue&bbs=<?cs var:html_escape(BBS) ?>&draft=<?cs var:html_escape(item.id) ?>&width=<?cs var:html_escape(item.width) ?>&height=<?cs var:html_escape(item.height) ?>&jpeg=<?cs var:html_escape(item.isJpeg) ?>&<?cs if:item.isPbbs ?>pbbs=1<?cs /if ?><?cs if:item.isShii ?>c_normal=1<?cs /if ?><?cs if:item.animation ?>&animation=1<?cs /if ?>">`</a><?cs if:isShii ?>(<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=continue&bbs=<?cs var:html_escape(BBS) ?>&draft=<?cs var:html_escape(item.id) ?>&width=<?cs var:html_escape(item.width) ?>&height=<?cs var:html_escape(item.height) ?>&jpeg=<?cs var:html_escape(item.isJpeg) ?>&c_pro=1<?cs if:item.animation ?>&animation=1<?cs /if ?>">yC^[PRO𗘗pꍇ͂</a>)<?cs /if ?>]
<?cs if:item.animation ?>[<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=animation&bbs=<?cs var:html_escape(BBS) ?>&draft=<?cs var:html_escape(item.id) ?>&width=<?cs var:html_escape(item.width) ?>&height=<?cs var:html_escape(item.height) ?>">`撆̓</a>]<?cs /if ?>
[<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=post&bbs=<?cs var:html_escape(BBS) ?>&draft=<?cs var:html_escape(item.id) ?>">e</a>]
[<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=remove&bbs=<?cs var:html_escape(BBS) ?>&draft=<?cs var:html_escape(item.id) ?>">폜</a>]<br><br>
</div>
<?cs /each ?>
<?cs else ?>
YIP瓊eꂽ܂B<br>
1ȏo߂ƎIɍ폜܂B
<?cs /if ?>
</td></tr>

</table>

</body>
</html>
